diff mbox series

[-next,16/24] spi: rzv2m-csi: switch to use modern name

Message ID 20230816094013.1275068-17-yangyingliang@huawei.com
State New
Headers show
Series spi: switch to use modern name (part4) | expand

Commit Message

Yang Yingliang Aug. 16, 2023, 9:40 a.m. UTC
Change legacy name master to modern name host.

No functional changed.

Signed-off-by: Yang Yingliang <yangyingliang@huawei.com>
---
 drivers/spi/spi-rzv2m-csi.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)
diff mbox series

Patch

diff --git a/drivers/spi/spi-rzv2m-csi.c b/drivers/spi/spi-rzv2m-csi.c
index d098aefa370d..7326d88e6bda 100644
--- a/drivers/spi/spi-rzv2m-csi.c
+++ b/drivers/spi/spi-rzv2m-csi.c
@@ -41,7 +41,7 @@ 
 #define CSI_CLKSEL_CKP		BIT(17)
 #define CSI_CLKSEL_DAP		BIT(16)
 #define CSI_CLKSEL_MODE		(CSI_CLKSEL_CKP|CSI_CLKSEL_DAP)
-#define CSI_CLKSEL_SLAVE	BIT(15)
+#define CSI_CLKSEL_TARGET	BIT(15)
 #define CSI_CLKSEL_CKS		GENMASK(14, 1)
 
 /* CSI_CNT */
@@ -70,7 +70,7 @@ 
 #define CSI_EN_DIS_TIMEOUT_US	100
 /*
  * Clock "csiclk" gets divided by 2 * CSI_CLKSEL_CKS in order to generate the
  * serial clock (output from master), with CSI_CLKSEL_CKS ranging from 0x1 (that
  * means "csiclk" is divided by 2) to 0x3FFF ("csiclk" is divided by 32766).
  */
 #define CSI_CKS_MAX		GENMASK(13, 0)
@@ -402,8 +402,8 @@  static int rzv2m_csi_setup(struct spi_device *spi)
 	rzv2m_csi_reg_write_bit(csi, CSI_MODE, CSI_MODE_DIR,
 				!!(spi->mode & SPI_LSB_FIRST));
 
-	/* Set the operation mode as master */
-	rzv2m_csi_reg_write_bit(csi, CSI_CLKSEL, CSI_CLKSEL_SLAVE, 0);
+	/* Set the operation mode as host */
+	rzv2m_csi_reg_write_bit(csi, CSI_CLKSEL, CSI_CLKSEL_TARGET, 0);
 
 	/* Give the IP a SW reset */
 	ret = rzv2m_csi_sw_reset(csi, 1);
@@ -555,7 +555,7 @@  static int rzv2m_csi_probe(struct platform_device *pdev)
 	int irq;
 	int ret;
 
-	controller = devm_spi_alloc_master(dev, sizeof(*csi));
+	controller = devm_spi_alloc_host(dev, sizeof(*csi));
 	if (!controller)
 		return -ENOMEM;
@@ -70,7 +70,7 @@ 
 /*
  * Clock "csiclk" gets divided by 2 * CSI_CLKSEL_CKS in order to generate the
- * serial clock (output from master), with CSI_CLKSEL_CKS ranging from 0x1 (that
+ * serial clock (output from host), with CSI_CLKSEL_CKS ranging from 0x1 (that
  * means "csiclk" is divided by 2) to 0x3FFF ("csiclk" is divided by 32766).
  */